@@ -2,7 +2,7 @@ package File::Stamped;
 use strict;
 use warnings;
 use 5.008001;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 use Carp ();
 use POSIX ();
 use SelectSaver ();
@@ -10,14 +10,22 @@ use SelectSaver ();
 sub new {
     my $class = shift;
     my %args = @_==1?%{$_[0]}:@_;
-    $args{pattern} || Carp::croak "missing mandatory parameter 'pattern'";
+    if (exists($args{pattern}) && exists($args{callback})) {
+        Carp::croak "Both 'pattern' and 'callback' cannot be specified.";
+    }
+    unless (exists($args{pattern}) || exists($args{callback})) {
+        Carp::croak "You need to specify 'pattern' or 'callback'.";
+    }
+    my $callback = delete($args{callback}) || _make_callback_from_pattern(delete($args{pattern}));
     my $self = bless \do { local *FH }, $class;
     tie *$self, $class, $self;
     %args = (
         autoflush         => 1,
         close_after_write => 1,
         iomode            => '>>:utf8',
-        %args
+        rotationtime      => 1,
+        callback          => $callback,
+        %args,
     );
     for my $k (keys %args) {
         *$self->{$k} = $args{$k};
@@ -37,7 +45,20 @@ sub PRINT     { shift->print(@_) }
 
 sub _gen_filename {
     my $self = shift;
-    return POSIX::strftime(*$self->{pattern}, localtime());
+    return *$self->{callback}->(*$self);
+}
+
+sub _make_callback_from_pattern {
+    my ($pattern) = shift;
+
+    return sub {
+        my $self = shift;
+        my $time = time();
+        if ( $time > 1 ) {
+            $time = $time - $time % $self->{rotationtime};
+        }
+        return POSIX::strftime($pattern, localtime($time));
+    };
 }
 
 sub print {
@@ -96,7 +117,9 @@ File::Stamped - time stamped log file
 
 =head1 DESCRIPTION
 
-File::Stamped is utility for time stamped log file.
+File::Stamped is utility library for logging. File::Stamped object mimic file handle.
+
+You can use "myapp.log.%Y%m%d.log" style log file.
 
 =head1 METHODS
 
@@ -106,6 +129,7 @@ File::Stamped is utility for time stamped log file.
 
 This method creates new instance of File::Stamped. The arguments are followings.
 
+You need to specify one of B<pattern> or B<callback>.
 
 =over 4
 
@@ -113,6 +137,23 @@ This method creates new instance of File::Stamped. The arguments are followings.
 
 This is file name pattern. It is the pattern for filename. The format is POSIX::strftime(), see also L<POSIX>.
 
+=item callback : CodeRef
+
+You can use a CodeRef to generate file name.
+
+File::Stamped pass only one arguments to callback function.
+
+Here is a example code:
+
+    my $pattern = '/path/to/myapp.log.%Y%m%d.log';
+    my $f = File::Stamped->new(callback => sub {
+        my $file_stamped = shift;
+        local $_ = $pattern;
+        s/!!/$$/ge;
+        $_ = POSIX::strftime($_, localtime());
+        return $_;
+    });
+
 =item close_after_write : Bool
 
 Default value is 1.
@@ -127,6 +168,10 @@ Default value is '>>:utf8'.
 
 This attribute changes $|.
 
+=item rotationtime: Int
+
+The time between log file generates in seconds. Default value is 1.
+
 =back
 
 =item $fh->print($str: Str)
@@ -137,7 +182,7 @@ This method prints the $str to the file.
 
 =head1 AUTHOR
 
-Tokuhiro Matsuno E<lt>tokuhirom AAJKLFJEF GMAIL COME<gt>
+Tokuhiro Matsuno E<lt>tokuhirom AAJKLFJEF@ gmail.comE<gt>
 
 =head1 SEE ALSO
 
